@@ -1,11 +1,11 @@
 /*
- * $Id: AssemblyInfo.cs 331 2008-07-27 13:44:05Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Engine/AssemblyInfo.cs $
- * $Rev: 331 $
- * $Author: meebey $
- * $Date: 2008-07-27 15:44:05 +0200 (Sun, 27 Jul 2008) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -31,7 +31,7 @@ using System.Reflection;
 using System.Runtime.CompilerServices;
 using System.Runtime.InteropServices;
 
-[assembly: AssemblyTitle("smuxi - engine")]
+[assembly: AssemblyTitle("Smuxi - engine")]
 [assembly: AssemblyCopyright("2005-2008 (C) Mirco Bauer <meebey@meebey.net>")]
 
 [assembly: AssemblyDelaySign(false)]
