@@ -1,11 +1,11 @@
 /*
- * $Id: Config.cs 464 2008-12-28 22:01:41Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Engine/Config/Config.cs $
- * $Rev: 464 $
- * $Author: meebey $
- * $Date: 2008-12-28 23:01:41 +0100 (Sun, 28 Dec 2008) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -194,6 +194,7 @@ namespace Smuxi.Engine
             
             // setting required default values
             prefix = "Server/";
+            Get(prefix+"BindAddress", "127.0.0.1");
             Get(prefix+"Port", 7689);
             Get(prefix+"Channel", "TCP");
             Get(prefix+"Formatter", "binary");
@@ -215,7 +216,7 @@ namespace Smuxi.Engine
             prefix = "Engine/Users/DEFAULT/Interface/Notebook/Channel/";
             Get(prefix+"UserListPosition", "left");
             Get(prefix+"TopicPosition", "top");
-            Get(prefix+"NickColors", false);
+            Get(prefix+"NickColors", true);
 
             prefix = "Engine/Users/DEFAULT/Interface/Chat/";
             Get(prefix+"BackgroundColor", String.Empty);
@@ -321,7 +322,7 @@ namespace Smuxi.Engine
                     // clean typical disallowed characters
                     nick = nick.Replace(" ", String.Empty);
                     if (String.IsNullOrEmpty(nick)) {
-                        nick = "smuxi";
+                        nick = "Smuxi";
                     }
                     m_Preferences[prefix+user+"/Connection/Nicknames"] = new string[] { nick };
                 }
@@ -342,7 +343,7 @@ namespace Smuxi.Engine
 #endif
                 }
                 if (String.IsNullOrEmpty(realname)) {
-                    realname = "http://smuxi.meebey.net";
+                    realname = "http://www.smuxi.org/";
                 }
                 LoadUserEntry(user, "Connection/Realname", realname);
                 LoadUserEntry(user, "Connection/Encoding", String.Empty);
@@ -360,6 +361,10 @@ namespace Smuxi.Engine
                 LoadUserEntry(user, "Interface/Notebook/EngineBufferLines", null);
                 LoadUserEntry(user, "Interface/Notebook/StripColors", null);
                 LoadUserEntry(user, "Interface/Notebook/StripFormattings", null);
+                LoadUserEntry(user, "Interface/Notebook/Tab/NoActivityColor", null);
+                LoadUserEntry(user, "Interface/Notebook/Tab/ActivityColor", null);
+                LoadUserEntry(user, "Interface/Notebook/Tab/EventColor", null);
+                LoadUserEntry(user, "Interface/Notebook/Tab/HighlightColor", null);
                 LoadUserEntry(user, "Interface/Notebook/Channel/UserListPosition", null);
                 LoadUserEntry(user, "Interface/Notebook/Channel/TopicPosition", null);
                 LoadUserEntry(user, "Interface/Notebook/Channel/NickColors", null);
@@ -495,6 +500,9 @@ namespace Smuxi.Engine
             if (isSection) {
                 m_IniDocument.Sections.Remove(iniSection);
             } else {
+                if (m_IniDocument.Sections[key] == null) {
+                    return;
+                }
                 m_IniDocument.Sections[key].Remove(key);
             }
 #endif
