@@ -1,11 +1,11 @@
 /*
- * $Id: FrontendManager.cs 479 2009-01-01 15:32:22Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Engine/FrontendManager.cs $
- * $Rev: 479 $
- * $Author: meebey $
- * $Date: 2009-01-01 16:32:22 +0100 (Thu, 01 Jan 2009) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2008 Mirco Bauer <meebey@meebey.net>
  *
@@ -149,8 +149,10 @@ namespace Smuxi.Engine
             
             // TODO: sort pages network tabs then channel tabs (alphabeticly)
             // sync pages            
-            foreach (ChatModel chat in _Session.Chats) {
-                _AddChat(chat);
+            lock (_Session.Chats) {
+                foreach (ChatModel chat in _Session.Chats) {
+                    _AddChat(chat);
+                }
             }
             
             // sync current network manager (if any exists)
@@ -160,11 +162,15 @@ namespace Smuxi.Engine
             }
             
             // sync current page
-            _CurrentChat = _Session.Chats[0];
+            lock (_Session.Chats) {
+                _CurrentChat = _Session.Chats[0];
+            }
             
             // sync content of pages
-            foreach (ChatModel chat in _Session.Chats) {
-                _SyncChat(chat);
+            lock (_Session.Chats) {
+                foreach (ChatModel chat in _Session.Chats) {
+                    _SyncChat(chat);
+                }
             }
             
             _IsFrontendSynced = true;
@@ -326,7 +332,7 @@ namespace Smuxi.Engine
             });
         }
     
-        public void UpdateTopicInGroupChat(GroupChatModel groupChat, string topic)
+        public void UpdateTopicInGroupChat(GroupChatModel groupChat, MessageModel topic)
         {
             if (!_SyncedChats.Contains(groupChat)) {
                 return;
@@ -335,7 +341,7 @@ namespace Smuxi.Engine
             _UpdateTopicInGroupChat(groupChat, topic);
         }
         
-        private void _UpdateTopicInGroupChat(GroupChatModel groupChat, string topic)
+        private void _UpdateTopicInGroupChat(GroupChatModel groupChat, MessageModel topic)
         {
             f_TaskQueue.Queue(delegate {
                 _UI.UpdateTopicInGroupChat(groupChat, topic);
@@ -398,7 +404,7 @@ namespace Smuxi.Engine
 #if LOG4NET
                 if (!_IsFrontendDisconnecting) {
                     // we didn't expect this problem
-                    _Logger.Error("RemotingException in TaskQueue, aborting thread...", e.Exception);
+                    _Logger.Error("RemotingException in TaskQueue: ", e.Exception);
                     _Logger.Error("Inner-Exception: ", e.Exception.InnerException);
                 }
 #endif
@@ -407,10 +413,13 @@ namespace Smuxi.Engine
                 // clean it good
             } else {
 #if LOG4NET
-                _Logger.Error("Exception in TaskQueue, aborting thread...", e.Exception);
+                _Logger.Error("Exception in TaskQueue: ", e.Exception);
                 _Logger.Error("Inner-Exception: ", e.Exception.InnerException);
 #endif
             }
+
+            // no need to remove us from the Session here as
+            // OnTaskQueueAbortedEvent will be raised after this and handle it
         }
         
         protected virtual void OnTaskQueueAbortedEvent(object sender, EventArgs e)
