@@ -5,7 +5,7 @@
  * $Author: meebey $
  * $Date: 2005-08-07 16:54:22 +0200 (Sun, 07 Aug 2005) $
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -27,6 +27,7 @@
  */
 
 using System;
+using System.Text;
 using System.Collections.Generic;
 using System.Runtime.Serialization;
 using Smuxi.Common;
@@ -103,5 +104,21 @@ namespace Smuxi.Engine
             GetObjectData(sw);
             sw.AddToInfo(info);
         }
+        
+        public override string ToString()
+        {
+            StringBuilder sb = new StringBuilder();
+
+            foreach (MessagePartModel part in MessageParts) {
+                if (part is UrlMessagePartModel) {
+                    UrlMessagePartModel url = (UrlMessagePartModel)part;
+                    sb.AppendFormat("{0} ", url.Url);
+                } else if (part is TextMessagePartModel) {
+                    TextMessagePartModel text = (TextMessagePartModel)part;
+                    sb.AppendFormat("{0} ", text.Text);
+                }
+            }
+            return sb.ToString().Trim();
+        }
     }
 }
