@@ -5,7 +5,7 @@
  * $Author: meebey $
  * $Date: 2005-08-07 16:54:22 +0200 (Sun, 07 Aug 2005) $
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -47,6 +47,9 @@ namespace Smuxi.Engine
                 return f_ForegroundColor;
             }
             set {
+                if (value == null) {
+                    value = TextColor.None;
+                }
                 f_ForegroundColor = value;
             }
         }
@@ -56,6 +59,9 @@ namespace Smuxi.Engine
                 return f_BackgroundColor;
             }
             set {
+                if (value == null) {
+                    value = TextColor.None;
+                }
                 f_BackgroundColor = value;
             }
         }
@@ -121,13 +127,13 @@ namespace Smuxi.Engine
             if (fgColor != null) {
                 f_ForegroundColor = fgColor;
             } else {
-                f_ForegroundColor = new TextColor();
+                f_ForegroundColor = TextColor.None;
             }
             
             if (bgColor != null) {
                 f_BackgroundColor = bgColor;
             } else {
-                f_BackgroundColor = new TextColor();
+                f_BackgroundColor = TextColor.None;
             }
             
             f_Underline = underline;
