@@ -5,7 +5,7 @@
  * $Author: meebey $
  * $Date: 2007-04-11 18:47:52 +0200 (Wed, 11 Apr 2007) $
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -89,9 +89,11 @@ namespace Smuxi.Engine
         public virtual IList<ChatModel> Chats {
             get {
                 IList<ChatModel> chats = new List<ChatModel>();
-                foreach (ChatModel chat in _Session.Chats) {
-                    if (chat.ProtocolManager == this) {
-                        chats.Add(chat);
+                lock (_Session.Chats) {
+                    foreach (ChatModel chat in _Session.Chats) {
+                        if (chat.ProtocolManager == this) {
+                            chats.Add(chat);
+                        }
                     }
                 }
                 return chats;
