@@ -1,11 +1,11 @@
 /*
- * $Id: Session.cs 481 2009-01-01 17:12:36Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Engine/Session.cs $
- * $Rev: 481 $
- * $Author: meebey $
- * $Date: 2009-01-01 18:12:36 +0100 (Thu, 01 Jan 2009) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -41,7 +41,7 @@ namespace Smuxi.Engine
 #endif
         private static readonly string                _LibraryTextDomain = "smuxi-engine";
         private int                                   _Version = 0;
-        private IDictionary<string, FrontendManager>  _FrontendManagers; 
+        private IDictionary<string, FrontendManager>  _FrontendManagers;
         private IList<IProtocolManager>               _ProtocolManagers;
         private IList<ChatModel>                      _Chats;
         private SessionChatModel                      _SessionChat;
@@ -135,7 +135,9 @@ namespace Smuxi.Engine
 #endif
             // add the FrontendManager to the hashtable with an unique .NET remoting identifier
             FrontendManager fm = new FrontendManager(this, ui);
-            _FrontendManagers[uri] = fm;
+            lock (_FrontendManagers) {
+                _FrontendManagers[uri] = fm;
+            }
             
             // if this is the first frontend, we process OnStartupCommands
             if (!_OnStartupCommandsProcessed) {
@@ -234,10 +236,12 @@ namespace Smuxi.Engine
             }
             
             string key = null;
-            foreach (KeyValuePair<string, FrontendManager> kv in _FrontendManagers) {
-                if (kv.Value == fm) {
-                    key = kv.Key;
-                    break;
+            lock (_FrontendManagers) {
+                foreach (KeyValuePair<string, FrontendManager> kv in _FrontendManagers) {
+                    if (kv.Value == fm) {
+                        key = kv.Key;
+                        break;
+                    }
                 }
             }
             if (key == null) {
@@ -250,7 +254,9 @@ namespace Smuxi.Engine
                 return;
             }
             
-            _FrontendManagers.Remove(key);
+            lock (_FrontendManagers) {
+                _FrontendManagers.Remove(key);
+            }
         }
         
         public void DeregisterFrontendUI(IFrontendUI ui)
@@ -265,7 +271,9 @@ namespace Smuxi.Engine
 #if LOG4NET
             f_Logger.Debug("Deregistering UI with URI: "+uri);
 #endif
-            _FrontendManagers.Remove(uri);
+            lock (_FrontendManagers) {
+                _FrontendManagers.Remove(uri);
+            }
         }
         
         public FrontendManager GetFrontendManager(IFrontendUI ui)
@@ -276,7 +284,9 @@ namespace Smuxi.Engine
                 throw new ArgumentNullException("ui");
             }
             
-            return _FrontendManagers[GetUri(ui)];
+            lock (_FrontendManagers) {
+                return _FrontendManagers[GetUri(ui)];
+            }
         }
         
         private string GetUri(IFrontendUI ui)
@@ -307,11 +317,13 @@ namespace Smuxi.Engine
                 throw new ArgumentNullException("id");
             }
             
-            foreach (ChatModel chat in _Chats) {
-                if ((chat.ID.ToLower() == id.ToLower()) &&
-                    (chat.ChatType == chatType) &&
-                    (chat.ProtocolManager == networkManager)) {
-                    return chat;
+            lock (_Chats) {
+                foreach (ChatModel chat in _Chats) {
+                    if ((chat.ID.ToLower() == id.ToLower()) &&
+                        (chat.ChatType == chatType) &&
+                        (chat.ProtocolManager == networkManager)) {
+                        return chat;
+                    }
                 }
             }
             
@@ -472,11 +484,13 @@ namespace Smuxi.Engine
             FrontendManager fm = cd.FrontendManager;
             if (cd.DataArray.Length >= 2) {
                 string server = cd.DataArray[1];
-                foreach (IProtocolManager nm in _ProtocolManagers) {
-                    if (nm.Host.ToLower() == server.ToLower()) {
-                        nm.Disconnect(fm);
-                        _ProtocolManagers.Remove(nm);
-                        return;
+                lock (_ProtocolManagers) {
+                    foreach (IProtocolManager nm in _ProtocolManagers) {
+                        if (nm.Host.ToLower() == server.ToLower()) {
+                            nm.Disconnect(fm);
+                            _ProtocolManagers.Remove(nm);
+                            return;
+                        }
                     }
                 }
                 fm.AddTextToCurrentChat(
@@ -569,11 +583,13 @@ namespace Smuxi.Engine
         {
             FrontendManager fm = cd.FrontendManager;
             fm.AddTextToCurrentChat("-!- " + _("Networks") + ":");
-            foreach (IProtocolManager nm in _ProtocolManagers) {
-                fm.AddTextToCurrentChat("-!- " +
-                    _("Type") + ": " + nm.Protocol + " " +
-                    _("Host") + ": " + nm.Host + " " + 
-                    _("Port") + ": " + nm.Port);
+            lock (_ProtocolManagers) {
+                foreach (IProtocolManager nm in _ProtocolManagers) {
+                    fm.AddTextToCurrentChat("-!- " +
+                        _("Type") + ": " + nm.Protocol + " " +
+                        _("Host") + ": " + nm.Host + " " + 
+                        _("Port") + ": " + nm.Port);
+                }
             }
         }
         
@@ -584,10 +600,12 @@ namespace Smuxi.Engine
             if (cd.DataArray.Length >= 3) {
                 // named protocol manager
                 string host = cd.DataArray[2].ToLower();
-                foreach (IProtocolManager protocolManager in _ProtocolManagers) {
-                    if (protocolManager.Host.ToLower() == host) {
-                        pm = protocolManager;
-                        break;
+                lock (_ProtocolManagers) {
+                    foreach (IProtocolManager protocolManager in _ProtocolManagers) {
+                        if (protocolManager.Host.ToLower() == host) {
+                            pm = protocolManager;
+                            break;
+                        }
                     }
                 }
                 if (pm == null) {
@@ -616,11 +634,13 @@ namespace Smuxi.Engine
             if (cd.DataArray.Length >= 3) {
                 // named network manager
                 string host = cd.DataArray[2].ToLower();
-                foreach (IProtocolManager nm in _ProtocolManagers) {
-                    if (nm.Host.ToLower() == host) {
-                        fm.CurrentProtocolManager = nm;
-                        fm.UpdateNetworkStatus();
-                        return;
+                lock (_ProtocolManagers) {
+                    foreach (IProtocolManager nm in _ProtocolManagers) {
+                        if (nm.Host.ToLower() == host) {
+                            fm.CurrentProtocolManager = nm;
+                            fm.UpdateNetworkStatus();
+                            return;
+                        }
                     }
                 }
                 fm.AddTextToCurrentChat("-!- " +
@@ -649,8 +669,10 @@ namespace Smuxi.Engine
         {
             Trace.Call();
             
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.UpdateNetworkStatus();
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.UpdateNetworkStatus();
+                }
             }
         }
         
@@ -662,9 +684,14 @@ namespace Smuxi.Engine
                 throw new ArgumentNullException("chat");
             }
             
-            _Chats.Add(chat);
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.AddChat(chat);
+            lock (_Chats) {
+                _Chats.Add(chat);
+            }
+            
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.AddChat(chat);
+                }
             }
         }
         
@@ -676,9 +703,14 @@ namespace Smuxi.Engine
                 throw new ArgumentNullException("chat");
             }
             
-            _Chats.Remove(chat);
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.RemoveChat(chat);
+            lock (_Chats) {
+                _Chats.Remove(chat);
+            }
+            
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.RemoveChat(chat);
+                }
             }
         }
         
@@ -691,8 +723,10 @@ namespace Smuxi.Engine
             }
             
             chat.IsEnabled = true;
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.EnableChat(chat);
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.EnableChat(chat);
+                }
             }
         }
         
@@ -705,8 +739,10 @@ namespace Smuxi.Engine
             }
             
             chat.IsEnabled = false;
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.DisableChat(chat);
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.DisableChat(chat);
+                }
             }
         }
         
@@ -718,8 +754,10 @@ namespace Smuxi.Engine
                 throw new ArgumentNullException("chat");
             }
             
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.SyncChat(chat);
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.SyncChat(chat);
+                }
             }
         }
         
@@ -752,8 +790,10 @@ namespace Smuxi.Engine
                 }
             }
             
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.AddMessageToChat(chat, msg);
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.AddMessageToChat(chat, msg);
+                }
             }
         }
         
@@ -769,8 +809,10 @@ namespace Smuxi.Engine
 #if LOG4NET
             f_Logger.Debug("AddPersonToGroupChat() groupChat.Name: "+groupChat.Name+" person.IdentityName: "+person.IdentityName);
 #endif
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.AddPersonToGroupChat(groupChat, person);
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.AddPersonToGroupChat(groupChat, person);
+                }
             }
         }
         
@@ -792,14 +834,19 @@ namespace Smuxi.Engine
                           " oldPerson.IdentityName: " + oldPerson.IdentityName +
                           " newPerson.IdentityName: " + newPerson.IdentityName);
 #endif
+            // FIXME: do we have to lock groupChat.UnsafePersons here?
+            // probably not, as long as the ProtocolManager who owns this chat
+            // is only running one thread
             groupChat.UnsafePersons.Remove(oldPerson.ID.ToLower());
             groupChat.UnsafePersons.Add(newPerson.ID.ToLower(), newPerson);
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.UpdatePersonInGroupChat(groupChat, oldPerson, newPerson);
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.UpdatePersonInGroupChat(groupChat, oldPerson, newPerson);
+                }
             }
         }
     
-        public void UpdateTopicInGroupChat(GroupChatModel groupChat, string topic)
+        public void UpdateTopicInGroupChat(GroupChatModel groupChat, MessageModel topic)
         {
             if (groupChat == null) {
                 throw new ArgumentNullException("groupChat");
@@ -809,11 +856,13 @@ namespace Smuxi.Engine
             }
 
 #if LOG4NET
-            f_Logger.Debug("UpdateTopicInGroupChat() groupChat.Name: " + groupChat.Name + " topic: " + topic);
+            f_Logger.Debug("UpdateTopicInGroupChat() groupChat.Name: " + groupChat.Name + " topic: " + topic.ToString());
 #endif
             groupChat.Topic = topic;
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.UpdateTopicInGroupChat(groupChat, topic);
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.UpdateTopicInGroupChat(groupChat, topic);
+                }
             }
         }
     
@@ -830,8 +879,10 @@ namespace Smuxi.Engine
             f_Logger.Debug("RemovePersonFromGroupChat() groupChat.Name: " + groupChat.Name + " person.ID: "+person.ID);
 #endif
             groupChat.UnsafePersons.Remove(person.ID.ToLower());
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.RemovePersonFromGroupChat(groupChat, person);
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.RemovePersonFromGroupChat(groupChat, person);
+                }
             }
         }
         
@@ -844,8 +895,10 @@ namespace Smuxi.Engine
 #if LOG4NET
             f_Logger.Debug("SetNetworkStatus() status: "+status);
 #endif
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.SetNetworkStatus(status);
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.SetNetworkStatus(status);
+                }
             }
         }
         
@@ -858,8 +911,10 @@ namespace Smuxi.Engine
 #if LOG4NET
             f_Logger.Debug("SetStatus() status: "+status);
 #endif
-            foreach (FrontendManager fm in _FrontendManagers.Values) {
-                fm.SetStatus(status);
+            lock (_FrontendManagers) {
+                foreach (FrontendManager fm in _FrontendManagers.Values) {
+                    fm.SetStatus(status);
+                }
             }
         }
         
