@@ -5,7 +5,7 @@
  * $Author: meebey $
  * $Date: 2005-08-07 16:54:22 +0200 (Sun, 07 Aug 2005) $
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -35,7 +35,9 @@ namespace Smuxi.Engine
     [Serializable]
     public class TextColor : ISerializable
     {
-        public static readonly TextColor None = new TextColor();
+        public static readonly TextColor None  = new TextColor();
+        public static readonly TextColor Black = new TextColor(0, 0, 0);
+        public static readonly TextColor White = new TextColor(255, 255, 255);
         
         private int f_Value;
         
