@@ -1,11 +1,11 @@
 /*
- * $Id: AboutDialog.cs 433 2008-10-11 15:42:54Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-GNOME/AboutDialog.cs $
- * $Rev: 433 $
- * $Author: meebey $
- * $Date: 2008-10-11 17:42:54 +0200 (Sat, 11 Oct 2008) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -27,7 +27,6 @@
  */
 
 using System;
-using Smuxi;
 
 namespace Smuxi.Frontend.Gnome
 {
@@ -43,7 +42,7 @@ namespace Smuxi.Frontend.Gnome
             Name = Frontend.Name;
             Version = "\n Frontend: " + Frontend.UIName + " " + Frontend.Version +
                       "\n Engine: " + Frontend.EngineVersion;
-            Copyright = "Copyright © 2005-2008 Mirco Bauer <meebey@meebey.net>";
+            Copyright = "Copyright © 2005-2009 Mirco Bauer <meebey@meebey.net>";
             Authors = new string[] {"Mirco Bauer <meebey@meebey.net>"};
             TranslatorCredits = _("German") + " - Mirco Bauer <meebey@meebey.net>\n" +
                                 _("Spanish") + " - Juan Miguel Carrero <streinleght@gmail.com>\n" +
