@@ -1,13 +1,13 @@
 /*
- * $Id: AssemblyInfo.cs 297 2008-07-17 20:36:34Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-GNOME/AssemblyInfo.cs $
- * $Rev: 297 $
- * $Author: meebey $
- * $Date: 2008-07-17 22:36:34 +0200 (Thu, 17 Jul 2008) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
- * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
+ * Copyright (c) 2005-2009 Mirco Bauer <meebey@meebey.net>
  *
  * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
  *
@@ -29,12 +29,8 @@
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-#if UI_GTK
-[assembly: AssemblyTitle("smuxi - GTK+ frontend")]
-#elif UI_GNOME
-[assembly: AssemblyTitle("smuxi - GNOME frontend")]
-#endif
-[assembly: AssemblyCopyright("2005-2008 (C) Mirco Bauer <meebey@meebey.net>")]
+[assembly: AssemblyTitle("Smuxi - GNOME frontend")]
+[assembly: AssemblyCopyright("2005-2009 (C) Mirco Bauer <meebey@meebey.net>")]
 
 [assembly: AssemblyDelaySign(false)]
 [assembly: AssemblyKeyFile("")]
