@@ -1,11 +1,11 @@
 /*
- * $Id: EngineManagerDialog.cs 448 2008-12-22 22:10:06Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-GNOME/EngineManagerDialog.cs $
- * $Rev: 448 $
- * $Author: meebey $
- * $Date: 2008-12-22 23:10:06 +0100 (Mon, 22 Dec 2008) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -58,8 +58,9 @@ namespace Smuxi.Frontend.Gnome
             _EngineManager = engineManager;
             
             Modal = true;
-            Title = "smuxi - " + _("Engine Manager");
-                
+            Title = "Smuxi - " + _("Engine Manager");
+            SetPosition(Gtk.WindowPosition.CenterAlways);
+
             Gtk.HBox connect_hbox = new Gtk.HBox();
             Gtk.Image connect_image = new Gtk.Image(new Gdk.Pixbuf(null,
                 "connect.png"));
@@ -86,7 +87,7 @@ namespace Smuxi.Frontend.Gnome
             
             Gtk.VBox vbox = new Gtk.VBox();
             Gtk.Label label = new Gtk.Label("<b>" + 
-                                            _("Select to which smuxi engine you want to connect") +
+                                            _("Select to which Smuxi engine you want to connect") +
                                             "</b>");
             label.UseMarkup = true;
             vbox.PackStart(label, false, false, 5);
@@ -141,14 +142,12 @@ namespace Smuxi.Frontend.Gnome
                     case 1:
                         _OnConnectButtonPressed();
                         break;
-#if UI_GNOME
                     case 2:
                         _OnEditButtonPressed();
                         break;
                     case 3:
                         _OnNewButtonPressed();
                         break;
-#endif
                     case 4:
                         _OnDeleteButtonPressed();
                         break;
@@ -158,14 +157,6 @@ namespace Smuxi.Frontend.Gnome
                     case (int)Gtk.ResponseType.DeleteEvent:
                         _OnDeleteEvent();
                         break;
-                    default:
-                        NotImplementedMessageDialog nid = new NotImplementedMessageDialog(this);
-                        nid.Run();
-                        nid.Destroy();
-                        
-                        // Re-run the Dialog
-                        Run();
-                        break;
                 }
             } catch (Exception ex) {
 #if LOG4NET
@@ -245,23 +236,60 @@ namespace Smuxi.Frontend.Gnome
             }
         }
 
-#if UI_GNOME
         private void _OnNewButtonPressed()
         {
-            // the druid will spawn EngineManagerDialog when it's canceled or finished
-            Destroy();
-            new EngineDruid(Frontend.FrontendConfig);
+            EngineAssistant assistant = new EngineAssistant(
+                this,
+                Frontend.FrontendConfig
+            );
+            assistant.Cancel += delegate {
+                assistant.Destroy();
+                
+                // Restart the Dialog
+                // HACK: holy shit, please refactor this mess!
+                EngineManagerDialog dialog = new EngineManagerDialog(_EngineManager);
+                dialog.Run();
+                dialog.Destroy();
+            };
+            assistant.Close += delegate {
+                assistant.Destroy();
+                
+                // Restart the Dialog
+                // HACK: holy shit, please refactor this mess!
+                EngineManagerDialog dialog = new EngineManagerDialog(_EngineManager);
+                dialog.Run();
+                dialog.Destroy();
+            };
+            assistant.ShowAll();
         }
-#endif
-
-#if UI_GNOME
+        
         private void _OnEditButtonPressed()
         {
-            // the druid will spawn EngineManagerDialog when it's canceled or finished
-            Destroy();
-            new EngineDruid(Frontend.FrontendConfig, _SelectedEngine);
+            EngineAssistant assistant = new EngineAssistant(
+                this,
+                Frontend.FrontendConfig,
+                _SelectedEngine
+            );
+            assistant.Cancel += delegate {
+                assistant.Destroy();
+
+                // Restart the Dialog
+                // HACK: holy shit, please refactor this mess!
+                EngineManagerDialog dialog = new EngineManagerDialog(_EngineManager);
+                dialog.Run();
+                dialog.Destroy();
+            };
+            assistant.Close += delegate {
+                assistant.Destroy();
+                
+                // Restart the Dialog
+                // HACK: holy shit, please refactor this mess!
+                EngineManagerDialog dialog = new EngineManagerDialog(_EngineManager);
+                dialog.Run();
+                dialog.Destroy();
+            };
+            assistant.ShowAll();
         }
-#endif
         
         private void _OnDeleteButtonPressed()
         {
@@ -272,12 +300,16 @@ namespace Smuxi.Frontend.Gnome
             Gtk.MessageType.Warning, Gtk.ButtonsType.YesNo, msg);
             int res = md.Run();
             md.Destroy();
+            
             if ((Gtk.ResponseType)res == Gtk.ResponseType.Yes) {
                 _DeleteEngine(_SelectedEngine);
-                _InitEngineList();
+                 _InitEngineList();
+                
+                // Re-run the Dialog
+                Run();
             }
         }
-        
+
         private void _DeleteEngine(string engine)
         {
             StringCollection new_engines = new StringCollection();
@@ -297,6 +329,10 @@ namespace Smuxi.Frontend.Gnome
             Frontend.FrontendConfig.Remove("Engines/"+engine+"/Port");
             Frontend.FrontendConfig.Remove("Engines/"+engine+"/Channel");
             Frontend.FrontendConfig.Remove("Engines/"+engine+"/Formatter");
+            Frontend.FrontendConfig.Remove("Engines/"+engine+"/UseSshTunnel");
+            Frontend.FrontendConfig.Remove("Engines/"+engine+"/SshHostname");
+            Frontend.FrontendConfig.Remove("Engines/"+engine+"/SshPort");
+            Frontend.FrontendConfig.Remove("Engines/"+engine+"/SshUsername");
             Frontend.FrontendConfig.Remove("Engines/"+engine);
             Frontend.FrontendConfig.Save();
             Frontend.FrontendConfig.Load();
