@@ -5,7 +5,7 @@
  * $Author: meebey $
  * $Date: 2008-07-12 19:00:51 +0200 (Sat, 12 Jul 2008) $
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2008 Mirco Bauer <meebey@meebey.net>
  *
@@ -126,7 +126,8 @@ namespace Smuxi.Frontend.Gnome
                         
                         Gtk.Application.Invoke(delegate {
                             foreach (GroupChatModel chat in chats) {
-                                f_ListStore.AppendValues(chat, chat.PersonCount, chat.Name, chat.Topic);
+                                // TODO: convert MessageModel into TreeView color
+                                f_ListStore.AppendValues(chat, chat.PersonCount, chat.Name, chat.Topic.ToString());
                             }
                         });
                     } catch (ThreadAbortException ex) {
