@@ -1,11 +1,11 @@
 /*
- * $Id: Frontend.cs 462 2008-12-28 22:01:24Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-GNOME/Frontend.cs $
- * $Rev: 462 $
- * $Author: meebey $
- * $Date: 2008-12-28 23:01:24 +0100 (Sun, 28 Dec 2008) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2008 Mirco Bauer <meebey@meebey.net>
  *
@@ -29,9 +29,6 @@
 using System;
 using System.IO;
 using System.Reflection;
-#if UI_GNOME
-using GNOME = Gnome;
-#endif
 using Smuxi.Engine;
 using Smuxi.Common;
 
@@ -42,15 +39,10 @@ namespace Smuxi.Frontend.Gnome
 #if LOG4NET
         private static readonly log4net.ILog _Logger = log4net.LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType);
 #endif
-        private static readonly string    _Name = "smuxi";
+        private static readonly string    _Name = "Smuxi";
         private static readonly string    _GladeFilename = "smuxi-frontend-gnome.glade";
-#if UI_GTK
-        private static readonly string    _UIName = "GTK+";
-#elif UI_GNOME
         private static readonly string    _UIName = "GNOME";
         private static int                _UIThreadID;
-        private static GNOME.Program      _Program;
-#endif
         private static Version            _Version;
         private static string             _VersionNumber;
         private static string             _VersionString;
@@ -106,14 +98,6 @@ namespace Smuxi.Frontend.Gnome
             }
         }
     
-#if UI_GNOME
-        public static GNOME.Program Program {
-            get {
-                return _Program;
-            }
-        }
-#endif
- 
         public static MainWindow MainWindow {
             get {
                 return _MainWindow;
@@ -206,14 +190,10 @@ namespace Smuxi.Frontend.Gnome
             _Logger.Debug("Using locale data from: " + localeDir);
 #endif
             
-#if UI_GNOME
-            _Program = new GNOME.Program(Name, Version.ToString(), GNOME.Modules.UI, args);
-#elif UI_GTK
-            Gtk.Application.Init(Name, args);
-#endif
+            Gtk.Application.Init(Name, ref args);
 #if GTK_SHARP_2_10
             GLib.ExceptionManager.UnhandledException += _OnUnhandledException;
-#endif           
+#endif
             //_SplashScreenWindow = new SplashScreenWindow();
 
             _FrontendConfig = new FrontendConfig(UIName);
@@ -235,6 +215,13 @@ namespace Smuxi.Frontend.Gnome
                         _MainWindow.Present();
                         return;
                     }
+                    // not everyone uses a window list applet thus we have to
+                    // restore from minimized state here, see:
+                    // http://projects.qnetp.net/issues/show/159
+                    if (_MainWindow.IsMinimized) {
+                        _MainWindow.Present();
+                        return;
+                    }
                     _MainWindow.Visible = !_MainWindow.Visible;
                 } catch (Exception ex) {
                     ShowException(ex);
@@ -258,16 +245,9 @@ namespace Smuxi.Frontend.Gnome
                 _SplashScreenWindow.Destroy();
             }
             
-#if UI_GNOME
-            _Program.Run();
-    #if LOG4NET
-            _Logger.Warn("_Program.Run() returned!");
-    #endif
-#elif UI_GTK
             Gtk.Application.Run();
-    #if LOG4NET
+#if LOG4NET
             _Logger.Warn("Gtk.Application.Run() returned!");
-    #endif
 #endif
         }
         
@@ -287,7 +267,10 @@ namespace Smuxi.Frontend.Gnome
         
         public static void ConnectEngineToGUI()
         {
-            _Session.RegisterFrontendUI(_MainWindow.UI);
+            if (_Session == _LocalSession) {
+                // HACK: SessionManager.Register() is not used for local engines
+                _LocalSession.RegisterFrontendUI(_MainWindow.UI);
+            }
             _FrontendManager = _Session.GetFrontendManager(_MainWindow.UI);
             _FrontendManager.Sync();
             
@@ -305,9 +288,12 @@ namespace Smuxi.Frontend.Gnome
             _MainWindow.ShowAll();
             // make sure entry got attention :-P
             _MainWindow.Entry.HasFocus = true;
-            
-            // check once per minute the status of the frontend manager
-            GLib.Timeout.Add(60 * 1000, _CheckFrontendManagerStatus);
+
+            // local sessions can't have network issues :)
+            if (_Session != _LocalSession) {
+                // check once per minute the status of the frontend manager
+                GLib.Timeout.Add(60 * 1000, _CheckFrontendManagerStatus);
+            }
         }
         
         public static void DisconnectEngineFromGUI()
@@ -318,6 +304,8 @@ namespace Smuxi.Frontend.Gnome
             _Session.DeregisterFrontendUI(_MainWindow.UI);
             _MainWindow.Hide();
             _MainWindow.Notebook.RemoveAllPages();
+            // make sure no stray SSH tunnel leaves behind
+            _MainWindow.EngineManager.Disconnect();
             
             _FrontendManager = null;
             _Session = null;
@@ -349,25 +337,13 @@ namespace Smuxi.Frontend.Gnome
             
             if (_FrontendManager != null) {
                 try {
-                    _FrontendManager.IsFrontendDisconnecting = true;
+                    DisconnectEngineFromGUI();
                 } catch (System.Runtime.Remoting.RemotingException ex) {
                     // the connection is maybe already gone
                 }
             }
             
-            /*
-            // WASBUG: don't do this, the access to config is lost and the entry will
-            // throw an exception then.
-            if (_FrontendManager != null) {
-                DisconnectEngineFromGUI();
-            }
-            */
-            
-#if UI_GNOME
-            _Program.Quit();
-#elif UI_GTK
             Gtk.Application.Quit();
-#endif
             
             Environment.Exit(0);
         }
