@@ -1,11 +1,11 @@
 /*
- * $Id: GnomeUI.cs 383 2008-08-25 19:46:55Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-GNOME/GnomeUI.cs $
- * $Rev: 383 $
- * $Author: meebey $
- * $Date: 2008-08-25 21:46:55 +0200 (Mon, 25 Aug 2008) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -200,7 +200,7 @@ namespace Smuxi.Frontend.Gnome
             });
         }
         
-        public void UpdateTopicInGroupChat(GroupChatModel ecpage, string topic)
+        public void UpdateTopicInGroupChat(GroupChatModel ecpage, MessageModel topic)
         {
             TraceRemotingCall(ecpage, topic);
 
@@ -209,9 +209,7 @@ namespace Smuxi.Frontend.Gnome
                 TraceRemotingCall(mb, ecpage, topic);
                 
                 GroupChatView cpage = (GroupChatView)Frontend.MainWindow.Notebook.GetChat(ecpage);
-                if (cpage.TopicEntry != null) {
-                    cpage.TopicEntry.Text = topic;
-                }
+                cpage.SetTopic(topic);
             });
         }
         
@@ -235,11 +233,7 @@ namespace Smuxi.Frontend.Gnome
             MethodBase mb = Trace.GetMethodBase();
             Gtk.Application.Invoke(delegate {
                 TraceRemotingCall(mb, status);
-#if UI_GNOME
-                Frontend.MainWindow.NetworkStatusbar.Push(status);
-#elif UI_GTK
                 Frontend.MainWindow.NetworkStatusbar.Push(0, status);
-#endif
             });
         }
         
@@ -250,11 +244,7 @@ namespace Smuxi.Frontend.Gnome
             MethodBase mb = Trace.GetMethodBase();
             Gtk.Application.Invoke(delegate {
                 TraceRemotingCall(mb, status);
-#if UI_GNOME
-                Frontend.MainWindow.Statusbar.Push(status);
-#elif UI_GTK
                 Frontend.MainWindow.Statusbar.Push(0, status);
-#endif
             });
         }
         
