@@ -1,11 +1,11 @@
 /*
- * $Id: MainWindow.cs 478 2008-12-31 18:17:56Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-GNOME/MainWindow.cs $
- * $Rev: 478 $
- * $Author: meebey $
- * $Date: 2008-12-31 19:17:56 +0100 (Wed, 31 Dec 2008) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2008 Mirco Bauer <meebey@meebey.net>
  *
@@ -30,30 +30,18 @@ using System;
 using System.IO;
 using System.Reflection;
 using Mono.Unix;
-#if UI_GNOME
-using GNOME = Gnome;
-#endif
 using Smuxi.Common;
 using Smuxi.Engine;
 
 namespace Smuxi.Frontend.Gnome
 {
-#if UI_GNOME
-    public class MainWindow : GNOME.App
-#elif UI_GTK
     public class MainWindow : Gtk.Window
-#endif
     {
 #if LOG4NET
         private static readonly log4net.ILog f_Logger = log4net.LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType);
 #endif
-#if UI_GNOME
-        private GNOME.AppBar     _NetworkStatusbar;
-        private GNOME.AppBar     _Statusbar;
-#elif UI_GTK
         private Gtk.Statusbar    _NetworkStatusbar;
         private Gtk.Statusbar    _Statusbar;
-#endif
         private Gtk.ProgressBar  _ProgressBar;
         private Entry            _Entry;
         private Notebook         _Notebook;
@@ -63,6 +51,7 @@ namespace Smuxi.Frontend.Gnome
         private EngineManager    _EngineManager;
         private Gtk.MenuItem     _CloseChatMenuItem;
         private NotificationAreaIconMode _NotificationAreaIconMode;
+        private bool             _IsMinimized;
         private bool             _IsMaximized;
         
         public bool CaretMode {
@@ -95,21 +84,13 @@ namespace Smuxi.Frontend.Gnome
             }
         }
         
-#if UI_GNOME
-        public new GNOME.AppBar NetworkStatusbar {
-#elif UI_GTK
         public new Gtk.Statusbar NetworkStatusbar {
-#endif
             get {
                 return _NetworkStatusbar;
             }
         } 
 
-#if UI_GNOME
-        public new GNOME.AppBar Statusbar {
-#elif UI_GTK
         public new Gtk.Statusbar Statusbar {
-#endif
             get {
                 return _Statusbar;
             }
@@ -133,11 +114,13 @@ namespace Smuxi.Frontend.Gnome
             }
         }
         
-#if UI_GNOME
-        public MainWindow() : base("smuxi", "smuxi - Smart MUtipleXed Irc")
-#elif UI_GTK
-        public MainWindow() : base("smuxi - Smart MUtipleXed Irc")
-#endif
+        public bool IsMinimized {
+            get {
+                return _IsMinimized;
+            }
+        }
+        
+        public MainWindow() : base("Smuxi - Smart MUtipleXed Irc")
         {
             // restore window size / position
             int width, heigth;
@@ -235,11 +218,21 @@ namespace Smuxi.Frontend.Gnome
             item.Submenu = menu;
             mb.Append(item);
             
+            image_item = new Gtk.ImageMenuItem(_("Open / Join Chat"));
+            image_item.Image = new Gtk.Image(Gtk.Stock.Open, Gtk.IconSize.Menu);
+            image_item.Activated += OnChatOpenChatButtonClicked;
+            menu.Append(image_item);
+                    
             image_item = new Gtk.ImageMenuItem(_("_Find Group Chat"));
             image_item.Image = new Gtk.Image(Gtk.Stock.Find, Gtk.IconSize.Menu);
             image_item.Activated += OnChatFindGroupChatButtonClicked;
             menu.Append(image_item);
             
+            image_item = new Gtk.ImageMenuItem(_("C_lear All Activity"));
+            image_item.Image = new Gtk.Image(Gtk.Stock.Clear, Gtk.IconSize.Menu);
+            image_item.Activated += OnChatClearAllActivityButtonClicked;
+            menu.Append(image_item);
+            
             menu.Append(new Gtk.SeparatorMenuItem());
                     
             image_item = new Gtk.ImageMenuItem(_("_Next Chat"));
@@ -357,6 +350,8 @@ namespace Smuxi.Frontend.Gnome
             _ChatViewManager.Load(asm);
             _ChatViewManager.LoadAll(System.IO.Path.GetDirectoryName(asm.Location),
                                      "smuxi-frontend-gnome-*.dll");
+            _ChatViewManager.ChatAdded += OnChatViewManagerChatAdded;
+            _ChatViewManager.ChatRemoved += OnChatViewManagerChatRemoved;
             
             _UI = new GnomeUI(_ChatViewManager);
             
@@ -367,25 +362,6 @@ namespace Smuxi.Frontend.Gnome
             
             _ProgressBar = new Gtk.ProgressBar();
             
-#if UI_GNOME
-            Menus = mb;
-            mb.ShowAll();
-            Gtk.VBox vbox = new Gtk.VBox();
-            vbox.PackStart(_Notebook, true, true, 0);
-            vbox.PackStart(_Entry, false, false, 0);
-            Contents = vbox;
-            
-            _NetworkStatusbar = new GNOME.AppBar(false, true, GNOME.PreferencesType.Never);
-            _NetworkStatusbar.WidthRequest = 300;
-            
-            _Statusbar = new GNOME.AppBar(false, true, GNOME.PreferencesType.Never);
-            
-            Gtk.HBox sb_hbox = new Gtk.HBox();
-            sb_hbox.PackStart(_NetworkStatusbar, false, true, 0);
-            sb_hbox.PackStart(_Statusbar, true, true, 0);
-            sb_hbox.PackStart(_ProgressBar, false, false, 0);
-            base.Statusbar = sb_hbox;
-#elif UI_GTK
             Gtk.VBox vbox = new Gtk.VBox();
             vbox.PackStart(mb, false, false, 0);
             vbox.PackStart(_Notebook, true, true, 0);
@@ -403,7 +379,6 @@ namespace Smuxi.Frontend.Gnome
             sb_hbox.PackStart(_ProgressBar, false, false, 0);
             vbox.PackStart(sb_hbox, false, false, 0);
             Add(vbox);
-#endif
         }
 
         public void ApplyConfig(UserConfig userConfig)
@@ -524,6 +499,8 @@ namespace Smuxi.Frontend.Gnome
                 
                 controller.AddServer(serverView.Server);
                 controller.Save();
+            } catch (InvalidOperationException ex) {
+                Frontend.ShowError(this, _("Unable to add server: "), ex);
             } catch (Exception ex) {
                 Frontend.ShowException(this, ex);
             }
@@ -541,6 +518,52 @@ namespace Smuxi.Frontend.Gnome
             }
         }
         
+        protected virtual void OnChatOpenChatButtonClicked(object sender, EventArgs e)
+        {
+            Trace.Call(sender, e);
+            
+            try {
+                OpenChatDialog dialog = new OpenChatDialog(this);
+                int res = dialog.Run();
+                
+                IProtocolManager manager = Frontend.FrontendManager.CurrentProtocolManager;
+                ChatModel chat;
+                switch (dialog.ChatType) {
+                    case ChatType.Group:
+                        chat = new GroupChatModel(
+                            dialog.ChatName, 
+                            dialog.ChatName,
+                            manager
+                        );
+                        break;
+                    case ChatType.Person:
+                        chat = new PersonChatModel(
+                            null,
+                            dialog.ChatName, 
+                            dialog.ChatName,
+                            manager
+                        );
+                        break;
+                    default:
+                        throw new ApplicationException(
+                            String.Format(
+                                _("Unknown ChatType: {0}"),
+                                dialog.ChatType
+                            )
+                        );
+                }
+                
+                dialog.Destroy();
+                if (res != (int) Gtk.ResponseType.Ok) {
+                    return;
+                }
+                
+                manager.OpenChat(Frontend.FrontendManager, chat);
+            } catch (Exception ex) {
+                Frontend.ShowException(this, ex);
+            }
+        }
+        
         protected virtual void OnChatFindGroupChatButtonClicked(object sender, EventArgs e)
         {
             Trace.Call(sender, e);
@@ -563,6 +586,17 @@ namespace Smuxi.Frontend.Gnome
             }
         }
         
+        protected virtual void OnChatClearAllActivityButtonClicked(object sender, EventArgs e)
+        {
+            Trace.Call(sender, e);
+            
+            try {
+                _Notebook.ClearAllActivity();
+            } catch (Exception ex) {
+                Frontend.ShowException(this, ex);
+            }
+        }
+        
         protected virtual void OnFindChatMenuItemActivated(object sender, EventArgs e)
         {
             Trace.Call(sender, e);
@@ -637,16 +671,24 @@ namespace Smuxi.Frontend.Gnome
             try {
 #if GTK_SHARP_2_10
                 // handle minimize / un-minimize
-                if (_NotificationAreaIconMode == NotificationAreaIconMode.Minimized &&
-                    (e.Event.ChangedMask & Gdk.WindowState.Iconified) != 0) {
-                    bool isMinimized = (e.Event.NewWindowState & Gdk.WindowState.Iconified) != 0;
+                if ((e.Event.ChangedMask & Gdk.WindowState.Iconified) != 0) {
+                    _IsMinimized = (e.Event.NewWindowState & Gdk.WindowState.Iconified) != 0;
     #if LOG4NET
-                    f_Logger.Debug("OnWindowStateEvent(): isMinimized: " + isMinimized);
+                    f_Logger.Debug("OnWindowStateEvent(): _IsMinimized: " + _IsMinimized);
     #endif
-                    Frontend.StatusIcon.Visible = isMinimized;
-                    if (isMinimized) {
-                        Hide();
+                    #if DISABLED
+                    if (_NotificationAreaIconMode == NotificationAreaIconMode.Minimized) {
+                        // BUG: metacity is not allowing us to use the minimize state
+                        // to hide and enable the notfication area icon as switching
+                        // to a different workspace sets WindowState.Iconified on all
+                        // windows, thus this code is disabled. For more details see:
+                        // http://projects.qnetp.net/issues/show/158
+                        Frontend.StatusIcon.Visible = _IsMinimized;
+                        if (isMinimized) {
+                            Hide();
+                        }
                     }
+                    #endif
                 }
 
                 // handle hide / show
@@ -740,7 +782,17 @@ namespace Smuxi.Frontend.Gnome
             Trace.Call(obj, args);
             
             try {
-                new EngineDruid(Frontend.FrontendConfig);
+                EngineAssistant assistant = new EngineAssistant(
+                    this,
+                    Frontend.FrontendConfig
+                );
+                assistant.Cancel += delegate {
+                    assistant.Destroy();
+                };
+                assistant.Close += delegate {
+                    assistant.Destroy();
+                };
+                assistant.ShowAll();
             } catch (Exception ex) {
                 Frontend.ShowException(this, ex);
             }
@@ -775,11 +827,11 @@ namespace Smuxi.Frontend.Gnome
                 
                 for (int i = 0; i < _Notebook.NPages; i++) {
                     ChatView chatView = _Notebook.GetChat(i);
-                    chatView.OutputTextView.CursorVisible = _CaretMode;
+                    chatView.OutputMessageTextView.CursorVisible = _CaretMode;
                 }
                 
                 if (_CaretMode) {
-                    _Notebook.CurrentChatView.OutputTextView.HasFocus = true;
+                    _Notebook.CurrentChatView.OutputMessageTextView.HasFocus = true;
                 } else {
                     _Entry.HasFocus = true;
                 }
@@ -789,6 +841,36 @@ namespace Smuxi.Frontend.Gnome
         }
 #endregion
         
+        protected void OnChatViewManagerChatAdded(object sender, ChatViewManagerChatAddedEventArgs e)
+        {
+            Trace.Call(sender, e);
+            
+            e.ChatView.OutputMessageTextView.MessageHighlighted += OnChatViewMessageHighlighted;
+        }
+        
+        protected void OnChatViewManagerChatRemoved(object sender, ChatViewManagerChatRemovedEventArgs e)
+        {
+            Trace.Call(sender, e);
+            
+            e.ChatView.OutputMessageTextView.MessageHighlighted -= OnChatViewMessageHighlighted;
+        }
+        
+        protected void OnChatViewMessageHighlighted(object sender, MessageTextViewMessageHighlightedEventArgs e)
+        {
+            Trace.Call(sender, e);
+            
+            if (!HasToplevelFocus) {
+                UrgencyHint = true;
+#if GTK_SHARP_2_10
+                Frontend.StatusIcon.Blinking = true;
+#endif
+                if (Frontend.UserConfig["Sound/BeepOnHighlight"] != null &&
+                    (bool)Frontend.UserConfig["Sound/BeepOnHighlight"]) {
+                    Display.Beep();
+                }
+            }
+        }
+
         private static string _(string msg)
         {
             return Mono.Unix.Catalog.GetString(msg);
