@@ -1,11 +1,11 @@
 /*
- * $Id: Notebook.cs 458 2008-12-28 21:13:04Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-GNOME/Notebook.cs $
- * $Rev: 458 $
- * $Author: meebey $
- * $Date: 2008-12-28 22:13:04 +0100 (Sun, 28 Dec 2008) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -114,6 +114,17 @@ namespace Smuxi.Frontend.Gnome
             }
         }
         
+        public void ClearAllActivity()
+        {
+            Trace.Call();
+            
+            int npages = NPages;
+            for (int i = 0; i < npages; i++) {
+                ChatView chat = GetChat(i);
+                chat.HasActivity = false;
+            }
+        }
+        
         // events
         private void _OnSwitchPage(object sender, Gtk.SwitchPageArgs e)
         {
@@ -144,7 +155,7 @@ namespace Smuxi.Frontend.Gnome
                     if (Frontend.MainWindow != null) {
                         string network = nmanager != null ? nmanager.ToString() + " / " : "";
                         Frontend.MainWindow.Title = network + chatView.Name +
-                                                    " - smuxi - Smart MUtipleXed Irc";
+                                                    " - Smuxi - Smart MUtipleXed Irc";
                     }
                 }
             } catch (Exception ex) {
