@@ -5,7 +5,7 @@
  * $Author: meebey $
  * $Date: 2007-06-12 02:57:23 +0200 (Tue, 12 Jun 2007) $
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2007 Mirco Bauer <meebey@meebey.net>
  *
@@ -29,7 +29,7 @@
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-[assembly: AssemblyTitle("smuxi - STFL frontend")]
+[assembly: AssemblyTitle("Smuxi - STFL frontend")]
 [assembly: AssemblyCopyright("2007-2008 (C) Mirco Bauer <meebey@meebey.net>")]
 
 [assembly: AssemblyDelaySign(false)]
