@@ -1,11 +1,11 @@
 /*
- * $Id: AssemblyInfo.cs 297 2008-07-17 20:36:34Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Server/AssemblyInfo.cs $
- * $Rev: 297 $
- * $Author: meebey $
- * $Date: 2008-07-17 22:36:34 +0200 (Thu, 17 Jul 2008) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -29,7 +29,7 @@
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-[assembly: AssemblyTitle("smuxi - server")]
+[assembly: AssemblyTitle("Smuxi - server")]
 [assembly: AssemblyCopyright("2005-2008 (C) Mirco Bauer <meebey@meebey.net>")]
 
 [assembly: AssemblyDelaySign(false)]
